@@ -77,9 +77,15 @@ class NxPyDocs():
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
                 if self.filetype != "json" or "yaml":
-                    command_output = clid( '%s' % self.command )
-                    parsed_json = json.loads(command_output)
-                    self.pick_filetype(parsed_json)                 
+                    if self.repo != "none":
+                        self.clone()
+                        self.pick_filetype(parsed_json)
+                        self.send_to_repo()
+                        self.cleanup()                    
+                    else: 
+                        command_output = clid( '%s' % self.command )
+                        parsed_json = json.loads(command_output)
+                        self.pick_filetype(parsed_json)                 
                 else:
                     command_output = clid( '%s' % self.command )
                     parsed_json = json.loads(command_output)
